
'=====================================================
'                                                    '
' MouseOverControls.inc (Version 2)                  '
' ---------------------------------                  '
'                                                    '
' This include code will let you know when the mouse ' 
' position is over a control that you specify.       '
'                                                    '
' By Andy - Enjoy.                                   '
'=====================================================


'=====================================================
' We need this function to get the mouse co-ordinates.
'=====================================================
$ifndef __windowssdk_inc__
    declare "user32",GetCursorPos(pPoint:POINTAPI),INT
$endif

Type CPos
     Def xposition:int
     Def yposition:int
Endtype

Def pt:Cpos

'========================================================
' Somewhere to store the control co-ordinates, sizes etc.
'========================================================
int ControlDown[1000]
int ControlAcross[1000]
int ControlWidth[1000]
int ControlHeight[1000]
int ControlNumber[1000]
int ControlOverNumber[1000]
UINT ControlsWindow[1000]
Uint WindowPointer[1000]
int WindowDown[1000]
int WindowAcross[1000]
int WindowWidth[1000]
int WindowHeight[1000]
int WindowOverNumber[1000]
string WindowName[1000]
string WindowDesc[1000]
string ControlType[1000]
string MouseOverType = ""

'=====================
' Some variables used.
'=====================
int ControlIndex,WindowIndex,ControlXpos,ControlYpos,WindowXpos,WindowYpos
int ycounter,zcounter,wcounter,wmcounter
int ControlUpdated,WindowUpdated
int MouseIsOver         = 0
int NoLongerOver        = 0
int MouseIsOverWindow   = 0
int MouseIsOverControl  = 0
int MouseIsOverControl2 = 0
int MouseIsOverControl3 = 0
int MouseIsOverControl4 = 0
int MouseIsOverControl5 = 0
int MouseIsOverControl6 = 0
int MouseIsOverControl7 = 0
int MouseIsOverControl8 = 0
int MouseIsOverControl9 = 0

'============================================================================================
' Store the control co-ordinates, but first check to see if the control for that window
' has already been stored - if so update the handle of the window for that control, otherwise
' it has not been stored before - so store it.
'============================================================================================
sub MouseOverControl(window MyWin,int MyControl,string MyWinDesc,string MyControlType)
WindowForMouse(MyWin,MyWinDesc)
ControlUpdated = 0

'================================================================================
' If control details have already been stored - update the window handle details.
'
' Closing a window and then re-opening it again causes that window to change It's
' handle details, so always update each control with the current window handle.
'================================================================================
if ControlIndex >= 1
   for zcounter = 1 to ControlIndex
       if ControlNumber[zcounter] = MyControl and WindowName[zcounter] = ltrim$(MyWinDesc)
          ControlsWindow[zcounter] = MyWin.hwnd
          ControlUpdated = 1
          breakfor
       endif
   next zcounter
endif

'==================================================================
' Control details have not yet been stored - so here we store them.
'==================================================================
if ControlUpdated = 0
   ControlIndex += 1
   GetSize MyWin,ControlAcross[ControlIndex],ControlDown[ControlIndex],ControlWidth[ControlIndex],ControlHeight[ControlIndex],MyControl
   ControlType[ControlIndex] = ltrim$(ucase$(MyControlType))
   ControlNumber[ControlIndex] = MyControl
   ControlsWindow[ControlIndex] = MyWin.hwnd
   WindowName[ControlIndex]   = ltrim$(MyWinDesc)
   ControlOverNumber[ControlIndex] = 0
endif

return 0
endsub

'=============================================================================================
' Here we check to see if the mouse is over a control - 0 false, 1 Moved over, 2 Remains over. 
'=============================================================================================
sub MouseOver(window ControlsWindowIn,INT ButtonIndex,string ControlsWindowDesc),int

    GetCursorPos(pt)
    ControlXpos = pt.xposition
    ControlYpos = pt.yposition

    MouseIsOverControl = 0
    MouseOverType = ""

    for zcounter = 1 to ControlIndex
        if ControlNumber[zcounter] = ButtonIndex and ControlsWindow[zcounter] = ControlsWindowIn.hwnd
           if ControlXpos >= ControlAcross[zcounter] and ControlXpos <= ControlAcross[zcounter] + ControlWidth[zcounter] and ControlYpos >= ControlDown[zcounter] and ControlYpos <= ControlDown[zcounter] + ControlHeight[zcounter] 
              if ControlOverNumber[zcounter] = 0
                 MouseIsOverControl = 1
                 ControlOverNumber[zcounter] = 1 
                 MouseOverType = ControlType[zcounter]
              else
                 MouseIsOverControl = 2
                 MouseOverType = ControlType[zcounter]
              endif
           else
              MouseIsOverControl = 0
              MouseOverType = ""
           endif
           breakfor
        endif
    next zcounter

return MouseIsOverControl
endsub

'=========================================================================
' Here we check to see if the mouse is over any control - 0 false, 1 true. 
'=========================================================================
sub MouseOverAnyControl(window ControlsWindowIn,string ControlsWindowDesc),int

    GetCursorPos(pt)
    ControlXpos = pt.xposition
    ControlYpos = pt.yposition

    for zcounter = 1 to ControlIndex
        if ControlsWindow[zcounter] = ControlsWindowIn.hwnd
           if ControlXpos >= ControlAcross[zcounter] and ControlXpos <= ControlAcross[zcounter] + ControlWidth[zcounter] and ControlYpos >= ControlDown[zcounter] and ControlYpos <= ControlDown[zcounter] + ControlHeight[zcounter] 
              MouseIsOverControl2 = 1
              breakfor
           else
              MouseIsOverControl2 = 0
           endif
        endif
    next zcounter

return MouseIsOverControl2
endsub

'=======================================================================================
' Here we check to see if the mouse is over any specific control type - 0 false, 1 true. 
'=======================================================================================
sub MouseOverControlType(window ControlsWindowIn,string ControlsWindowDesc,string ControlsType),int

    ' Control type parameters: 

    ' B - Button
    ' C - Checkbox
    ' E - Edit
    ' L - Listbox
    ' R - Radio
    ' S - Static
    ' V - Listview 

    GetCursorPos(pt)
    ControlXpos = pt.xposition
    ControlYpos = pt.yposition

    for zcounter = 1 to ControlIndex
        if ControlsWindow[zcounter] = ControlsWindowIn.hwnd
           if ControlXpos >= ControlAcross[zcounter] and ControlXpos <= ControlAcross[zcounter] + ControlWidth[zcounter] and ControlYpos >= ControlDown[zcounter] and ControlYpos <= ControlDown[zcounter] + ControlHeight[zcounter] and ucase$(ControlsType) = ControlType[zcounter]
              MouseIsOverControl3 = 1
              breakfor
           else
              MouseIsOverControl3 = 0
           endif
        endif
    next zcounter

return MouseIsOverControl3
endsub

'===============================================================================================
' Here we check if control was pointed to but is no longer pointed at - Returns 1 true, 0 false.  
'===============================================================================================
sub MouseMovedOff(window ControlsWindowIn,INT MovedOff,string MovedOffDesc),int

    NoLongerOver = 0

    for ycounter = 1 to ControlIndex
        if ControlNumber[ycounter] = MovedOff and ControlsWindow[ycounter] = ControlsWindowIn.hwnd
           if ControlOverNumber[ycounter] = 1 and MouseIsOverControl <> 2
              ControlOverNumber[ycounter] = 0
              NoLongerOver = 1 
           endif
           breakfor
        endif
    next ycounter

return NoLongerOver
endsub

'===========================================================================
' Store the window co-ordinates, but first check to see if the window
' has already been stored - if so update the handle of the window, otherwise
' it has not been stored before - so store it.
'===========================================================================
sub WindowForMouse(window MyWin,string MyWinDesc)

WindowUpdated = 0

'================================================================================
' If window details have already been stored - update the window handle details.
'
' Closing a window and then re-opening it again causes that window to change It's
' handle details, so always update each control with the current window handle.
'================================================================================
if WindowIndex >= 1
   for wcounter = 1 to WindowIndex
       if WindowDesc[wcounter] = ltrim$(MyWinDesc)
          WindowPointer[wcounter] = MyWin.hwnd
          WindowUpdated = 1
          breakfor
       endif
   next wcounter
endif

'=================================================================
' Window details have not yet been stored - so here we store them.
'=================================================================
if WindowUpdated = 0
   WindowIndex += 1
   GetSize MyWin,WindowAcross[WindowIndex],WindowDown[WindowIndex],WindowWidth[WindowIndex],WindowHeight[WindowIndex]
   WindowPointer[WindowIndex] = MyWin.hwnd
   WindowDesc[WindowIndex]   = ltrim$(MyWinDesc)
   WindowOverNumber[WindowIndex] = 0
endif

return 0
endsub

'==============================================================================
' Here we check to see if the mouse is over the window - 0 false, 1 Moved over. 
'==============================================================================
sub TrackWindow(window WindowIn,string WindowInDesc),int

GetCursorPos(pt)
WindowXpos = pt.xposition
WindowYpos = pt.yposition

	for wcounter = 1 to WindowIndex
	  if WindowPointer[wcounter] = WindowIn.hwnd and WindowDesc[wcounter] = ltrim$(WindowInDesc)

		  '=============================================
		  ' Update the window with it's new coordinates.
		  '=============================================

		  GetSize WindowIn,WindowAcross[wcounter],WindowDown[wcounter],WindowWidth[wcounter],WindowHeight[wcounter]

		  '======================================================
		  ' Here we check to see if the mouse is over the window.
		  '======================================================

		  if WindowXpos >= WindowAcross[wcounter] and WindowXpos <= WindowAcross[wcounter] + WindowWidth[wcounter] and WindowYpos >= WindowDown[wcounter] and WindowYpos <= WindowDown[wcounter] + WindowHeight[wcounter] 
			  MouseIsOverWindow = 1
		  else
			  MouseIsOverWindow = 0
		  endif
		  breakfor
	  endif
	next wcounter

   '===========================================================
   ' Update the controls with their new co-ordinates and sizes. 
   '===========================================================

	for wmcounter = 1 to ControlIndex

 		 if ControlsWindow[wmcounter] = WindowIn.hwnd and WindowName[wmcounter] = ltrim$(WindowInDesc)
          getsize WindowIn,ControlAcross[wmcounter],ControlDown[wmcounter],ControlWidth[wmcounter],ControlHeight[wmcounter],ControlNumber[wmcounter]
		 endif

	next wmcounter

return MouseIsOverWindow
endsub

'=============================
' End of MouseOverControls.inc
'=============================
